; task: sum N 4 bit numbers in a 8 bit accumulator with overflow detection
; input on paper:
;  3: number of operands (N)
;  4..N+4: operands
;
; output on paper:
;  0: sum, least significant nibble
;  1: sum, most significant nibble
;  2: non-zero on overflow
	BTS STATUS, 3   ; SI: paper

	; set SI to 3
	LDA 3
	MOVE SI, A

  ; load number of operands in cntr (6)
	LDA 6
	MOVE DI, A
	LDAS
	STAD

	; reset DI to 0
	LDA 0
	MOVE DI, A

	; set SI to 4
	LDA 4
	MOVE SI, A

@loop:
	LDA 0           ; make sure DI is 0
	MOVE DI, A
	ADDSDC          ; add [DI] and [SI]

	; if carry was 1 from last operation, set DI to 1 and increment
	SKC
	JMP noc
	LDA 1
	MOVE DI, A
	LDA 1
	ADDAD

	; check if it causes overflow
	SKC
	JMP noc

	; if we have carry again, sum can not be stored on 8 bits, set error nibble on paper
	LDA 2
	MOVE SI, A
	LDA 1
	STAS
	FIN

@noc:
	LOOPI
	JMP loop

	; copy ram 0 and 1 on paper
	BTC STATUS, 3   ; SI: ram
	BTS STATUS, 2   ; DI: paper

	LDA 0
	MOVE SI, A
	MOVE DI, A

	; copy 2 nibbles
	LDAS
	STAD
	LOOPI
	NOP

	LDAS
	STAD
	LOOPI
	NOP

	FIN
